@@ -1,38 +1,16 @@
-/*
- * Copyright (C) 2013 Alexey Galakhov <agalakhov@gmail.com>
- *
- * Licensed under the GNU General Public License Version 3
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
-
 #ifndef __RANDR_CONN_PRIVATE_H__
 #define __RANDR_CONN_PRIVATE_H__
 
+#include <colord.h>
 #include "randr-conn.h"
-
 #include <glib.h>
 #include <glib-object.h>
-
-#include <colord.h>
-
-#include <X11/Xlib.h>
 #include <X11/extensions/Xrandr.h>
+#include <X11/Xlib.h>
 
 G_BEGIN_DECLS
 
-struct randr_conn {
+typedef struct randr_conn {
 	GObject		*object;
 	Display		*dpy;
 	int		event_base;
@@ -40,7 +18,7 @@ struct randr_conn {
 	Atom		edid_atom;
 	Atom		type_atom;
 	GPtrArray	*displays;
-};
+} RandrConnPrivate;
 
 struct randr_display_priv {
 	struct randr_display	pub;
@@ -65,15 +43,17 @@ enum {
 
 extern guint randr_signals[N_SIG];
 
+typedef const gchar *(*get_find_key_fn)(struct randr_display *);
+
 void randr_conn_private_init (struct randr_conn *conn, const gchar *disp_name);
 void randr_conn_private_finalize (struct randr_conn *conn);
 void randr_conn_private_start (struct randr_conn *conn);
 void randr_conn_private_update (struct randr_conn *conn);
 struct randr_display *randr_conn_private_find_display (struct randr_conn *conn,
-						       const gchar *key, guint offset);
+						       const gchar *key,
+						       get_find_key_fn get_find_key);
 void randr_display_private_apply_icc (struct randr_display *disp, CdIcc *icc);
 
-
 G_END_DECLS
 
 #endif /* __RANDR_CONN_PRIVATE_H__ */
