@@ -1,28 +1,8 @@
-/*
- * Copyright (C) 2013 Alexey Galakhov <agalakhov@gmail.com>
- *
- * Licensed under the GNU General Public License Version 3
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
-
-#include "randr-conn.h"
 #include "icc.h"
-
+#include "randr-conn.h"
+#include <colord.h>
 #include <glib.h>
 #include <glib-unix.h>
-#include <colord.h>
 #include <string.h>
 
 typedef struct _Daemon {
@@ -32,6 +12,10 @@ typedef struct _Daemon {
 	CdIccStore	*stor;
 } Daemon;
 
+static struct {
+	const gchar	*display;
+	      gboolean	edid;
+} config;
 
 static void
 show_version (void)
@@ -40,19 +24,14 @@ show_version (void)
 	exit (0);
 }
 
-static struct {
-	const gchar	*display;
-	      gboolean	edid;
-} config;
-
 static GOptionEntry config_entries[] = {
 	{ "version", 'V', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK,
 		(void*)(intptr_t) show_version,
 		"Show version", NULL },
 	{ "display", 'd', 0, G_OPTION_ARG_STRING, &config.display,
-		"X server to contact", NULL },
+		"Uses a specific display", NULL },
 	{ "edid", 'e', 0, G_OPTION_ARG_NONE, &config.edid,
-		"Generate EDID profile", NULL },
+		"Generates a default color profile based on the display model", NULL },
 	{ NULL }
 };
 
@@ -78,9 +57,10 @@ profile_id (CdIcc *icc)
 }
 
 static gchar *
-profile_filename (const struct edid *edid)
+profile_filename (CdEdid *edid)
 {
-	return g_strdup_printf ("edid-%s.icc", edid->cksum);
+	const gchar *cksum = cd_edid_get_checksum (edid);
+	return g_strdup_printf ("edid-%s.icc", cksum);
 }
 
 static void
@@ -107,7 +87,7 @@ update_device_cb (GObject *src, GAsyncResult *res, gpointer user_data)
         }
 
 	xrandr_id = cd_device_get_id (device);
-	disp = randr_conn_find_display (daemon->rcon, xrandr_id);
+	disp = randr_conn_find_display_by_name (daemon->rcon, xrandr_id);
 	if (! disp) {
 		g_critical ("device '%s' does not exist", xrandr_id);
 		goto out;
@@ -187,7 +167,7 @@ update_profile_cb (GObject *src, GAsyncResult *res, gpointer user_data)
 	if (! edid_md5)
 		goto out;
 
-	disp = randr_conn_find_display_edid (daemon->rcon, edid_md5);
+	disp = randr_conn_find_display_by_edid (daemon->rcon, edid_md5);
 	if (! disp)
 		goto out;
 
@@ -218,7 +198,6 @@ out:
 		g_object_unref (device);
 }
 
-
 static void
 update_device (CdDevice *device, Daemon *daemon)
 {
@@ -231,7 +210,6 @@ update_profile (CdProfile *profile, Daemon *daemon)
 	cd_profile_connect (profile, NULL, update_profile_cb, daemon);
 }
 
-
 static void
 cd_profile_added_sig (CdClient *client, CdProfile *profile, Daemon *daemon)
 {
@@ -253,7 +231,6 @@ cd_device_changed_sig (CdClient *client, CdDevice *device, Daemon *daemon)
 	update_device (device, daemon);
 }
 
-
 static void
 cd_create_device_cb (GObject *src, GAsyncResult *res, gpointer user_data)
 {
@@ -274,9 +251,8 @@ cd_create_device_cb (GObject *src, GAsyncResult *res, gpointer user_data)
 	g_object_unref (dev);
 }
 
-
 static void
-create_profile_from_edid(CdIccStore *store, const struct edid *edid)
+create_profile_from_edid(CdIccStore *store, CdEdid *edid)
 {
 	gchar *filename;
 	gchar *filepath;
@@ -284,6 +260,7 @@ create_profile_from_edid(CdIccStore *store, const struct edid *edid)
 	CdIcc *icc = NULL;
 	GError *err = NULL;
 	gboolean ret;
+	const gchar *cksum = cd_edid_get_checksum (edid);
 
 	filename = profile_filename (edid);
 	filepath = g_build_filename (g_get_user_data_dir (), "icc", filename, NULL);
@@ -293,17 +270,17 @@ create_profile_from_edid(CdIccStore *store, const struct edid *edid)
 
 	icc = cd_icc_store_find_by_filename (store, g_file_get_path (file));
 	if (icc) {
-		g_debug ("profile for edid %s already exists", edid->cksum);
+		g_debug ("profile for edid %s already exists", cksum);
 		goto out;
 	}
 
 	icc = icc_from_edid (edid);
 	if (! icc) {
-		g_critical ("profile for EDID %s was not created", edid->cksum);
+		g_critical ("profile for EDID %s was not created", cksum);
 		goto out;
 	}
 
-	g_debug ("WRITING profile for EDID %s", edid->cksum);
+	g_debug ("WRITING profile for EDID %s", cksum);
 
 	ret = cd_icc_save_file (icc, file, CD_ICC_SAVE_FLAGS_NONE, NULL, &err);
 	if (! ret) {
@@ -318,10 +295,10 @@ out:
 	g_object_unref (file);
 }
 
-
 static void
 randr_display_added_sig (RandrConn *conn, struct randr_display *disp, Daemon *daemon)
 {
+	const gchar *cksum;
 	GHashTable *props = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, NULL);
 
 	g_assert (conn == daemon->rcon);
@@ -329,7 +306,7 @@ randr_display_added_sig (RandrConn *conn, struct randr_display *disp, Daemon *da
 	g_debug ("added display: '%s'", disp->name);
 
 	if (config.edid) {
-		create_profile_from_edid (daemon->stor, &disp->edid);
+		create_profile_from_edid (daemon->stor, disp->edid);
 	}
 
 	g_hash_table_insert (props, CD_DEVICE_PROPERTY_KIND,
@@ -339,9 +316,9 @@ randr_display_added_sig (RandrConn *conn, struct randr_display *disp, Daemon *da
 	g_hash_table_insert (props, CD_DEVICE_PROPERTY_COLORSPACE,
 			     (gchar *) cd_colorspace_to_string (CD_COLORSPACE_RGB));
 
-	g_hash_table_insert (props, CD_DEVICE_PROPERTY_VENDOR, (gchar *) disp->edid.vendor);
-	g_hash_table_insert (props, CD_DEVICE_PROPERTY_MODEL, (gchar *) disp->edid.model);
-	g_hash_table_insert (props, CD_DEVICE_PROPERTY_SERIAL, (gchar *) disp->edid.serial);
+	g_hash_table_insert (props, CD_DEVICE_PROPERTY_VENDOR, (gchar *) cd_edid_get_vendor_name (disp->edid));
+	g_hash_table_insert (props, CD_DEVICE_PROPERTY_MODEL, (gchar *) cd_edid_get_monitor_name (disp->edid));
+	g_hash_table_insert (props, CD_DEVICE_PROPERTY_SERIAL, (gchar *) cd_edid_get_serial_number (disp->edid));
 
 	g_hash_table_insert (props, CD_DEVICE_METADATA_XRANDR_NAME, (gchar *) disp->xrandr_name);
 
@@ -349,9 +326,9 @@ randr_display_added_sig (RandrConn *conn, struct randr_display *disp, Daemon *da
 			     disp->is_primary ? CD_DEVICE_METADATA_OUTPUT_PRIORITY_PRIMARY
 					      : CD_DEVICE_METADATA_OUTPUT_PRIORITY_SECONDARY);
 
-	if (disp->edid.cksum)
-		g_hash_table_insert (props, CD_DEVICE_METADATA_OUTPUT_EDID_MD5,
-				     (gchar *) disp->edid.cksum);
+	cksum = cd_edid_get_checksum (disp->edid);
+	if (cksum)
+		g_hash_table_insert (props, CD_DEVICE_METADATA_OUTPUT_EDID_MD5, (gchar *) cksum);
 
 	if (disp->is_laptop)
 		g_hash_table_insert (props, CD_DEVICE_PROPERTY_EMBEDDED, NULL);
@@ -612,8 +589,6 @@ cd_connect_cb (GObject *src, GAsyncResult *res, gpointer user_data)
 	randr_conn_start (daemon->rcon);
 }
 
-
-
 int
 main (int argc, char *argv[])
 {
